Commit 3a40847c60d489b15b351730c8947c92f42ecae3

Werner Lemberg 2000-11-06T04:33:56

Added/restored the `*' convention for output parameters. Some documentation fixes.

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
diff --git a/docs/convntns.txt b/docs/convntns.txt
index 327f438..0841383 100644
--- a/docs/convntns.txt
+++ b/docs/convntns.txt
@@ -334,7 +334,20 @@ points:
 
       FT_Int*  pointer;
 
-    As  mentioned   above,  multiple  declarations   are  vertically
+    However,  when declaring resp.   defining an  `output' parameter
+    (i.e. a  pointer which  will be assigned  by the  function), the
+    last `*' must be placed on the right in order to denote this, as
+    in:
+
+      FT_New_Face( FT_Library  library,
+                   FT_Face    *aface );
+
+    where the `*' is used  to indicate that `aface' is returned.  In
+    most cases, the name of  such an output variable starts with `a'
+    or `an'  (`aface' instead of  `face', `anlru' instead  of `lru',
+    etc.), following the English rules of the indefinite article.
+
+  . As  mentioned   above,  multiple  declarations   are  vertically
     aligned:
 
       FT_Short      foo;
@@ -359,9 +372,11 @@ points:
       x = sin( y );
       y = sizeof ( long );
 
-    Except for casts, parentheses are surrounded with space:
+    Except for  casts, empty parameters, and  the closing semicolon,
+    parentheses are surrounded with space:
 
       x = (char*)( foo + bar );
+      y = rand();
 
   . Binary operators are surrounded by spaces; unary operators have
     no space after it:
@@ -379,6 +394,12 @@ points:
       if ( x = 0; x < y; x++, y-- )
         do_something();
 
+    Exception:
+
+      for (;;)
+      {
+        ...
+
   . Don't use
 
       if ( x == y ) a = b;
diff --git a/include/freetype/cache/ftcchunk.h b/include/freetype/cache/ftcchunk.h
index afee39e..3866659 100644
--- a/include/freetype/cache/ftcchunk.h
+++ b/include/freetype/cache/ftcchunk.h
@@ -185,13 +185,13 @@
 
   FT_EXPORT( FT_Error )  FTC_ChunkSet_New( FTC_Chunk_Cache  cache,
                                            FT_Pointer       type,
-                                           FTC_ChunkSet*    aset );
+                                           FTC_ChunkSet    *aset );
 
   FT_EXPORT( FT_Error )  FTC_ChunkSet_Lookup_Node(
                                FTC_ChunkSet    cset,
                                FT_UInt         glyph_index,
                                FTC_ChunkNode*  anode,
-                               FT_UInt*        aindex );
+                               FT_UInt        *anindex );
 
 
 #ifdef __cplusplus
diff --git a/include/freetype/cache/ftcglyph.h b/include/freetype/cache/ftcglyph.h
index 6e2383e..2614c04 100644
--- a/include/freetype/cache/ftcglyph.h
+++ b/include/freetype/cache/ftcglyph.h
@@ -189,12 +189,12 @@
 
   FT_EXPORT( FT_Error )  FTC_GlyphSet_New( FTC_Glyph_Cache  cache,
                                            FT_Pointer       type,
-                                           FTC_GlyphSet*    aset );
+                                           FTC_GlyphSet    *aset );
 
   FT_EXPORT( FT_Error )  FTC_GlyphSet_Lookup_Node(
                            FTC_GlyphSet    gset,
                            FT_UInt         glyph_index,
-                           FTC_GlyphNode*  anode );
+                           FTC_GlyphNode  *anode );
 
 
 #ifdef __cplusplus
diff --git a/include/freetype/cache/ftcimage.h b/include/freetype/cache/ftcimage.h
index bf5435c..8c457c7 100644
--- a/include/freetype/cache/ftcimage.h
+++ b/include/freetype/cache/ftcimage.h
@@ -120,7 +120,7 @@
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FTC_Image_Cache_New( FTC_Manager       manager,
-                                              FTC_Image_Cache*  acache );
+                                              FTC_Image_Cache  *acache );
 
 
   /*************************************************************************/
@@ -157,7 +157,7 @@
   FT_EXPORT( FT_Error )  FTC_Image_Cache_Lookup( FTC_Image_Cache  cache,
                                                  FTC_Image_Desc*  desc,
                                                  FT_UInt          gindex,
-                                                 FT_Glyph*        aglyph );
+                                                 FT_Glyph        *aglyph );
 
 
 #ifdef __cplusplus
diff --git a/include/freetype/cache/ftcsbits.h b/include/freetype/cache/ftcsbits.h
index 71c28a1..a167f69 100644
--- a/include/freetype/cache/ftcsbits.h
+++ b/include/freetype/cache/ftcsbits.h
@@ -54,7 +54,7 @@
 
 
   FT_EXPORT( FT_Error )  FTC_SBit_Cache_New( FTC_Manager      manager,
-                                             FTC_SBit_Cache*  acache );
+                                             FTC_SBit_Cache  *acache );
 
   FT_EXPORT( FT_Error )  FTC_SBit_Cache_Lookup( FTC_SBit_Cache   cache,
                                                 FTC_Image_Desc*  desc,
diff --git a/include/freetype/cache/ftlru.h b/include/freetype/cache/ftlru.h
index 25fa3fb..d9b2e5f 100644
--- a/include/freetype/cache/ftlru.h
+++ b/include/freetype/cache/ftlru.h
@@ -146,7 +146,7 @@
                                      FT_Pointer           user_data,
                                      FT_Memory            memory,
                                      FT_Bool              pre_alloc,
-                                     FT_Lru*              alru );
+                                     FT_Lru              *anlru );
 
   FT_EXPORT( void )      FT_Lru_Reset( FT_Lru  lru );
 
@@ -155,11 +155,11 @@
 
   FT_EXPORT( FT_Error )  FT_Lru_Lookup_Node( FT_Lru        lru,
                                              FT_LruKey     key,
-                                             FT_LruNode*  anode );
+                                             FT_LruNode   *anode );
 
   FT_EXPORT( FT_Error )  FT_Lru_Lookup( FT_Lru       lru,
                                         FT_LruKey    key,
-                                        FT_Pointer*  aobject );
+                                        FT_Pointer  *anobject );
 
 
   FT_EXPORT( void )  FT_Lru_Remove_Node( FT_Lru      lru,
diff --git a/include/freetype/ftcache.h b/include/freetype/ftcache.h
index fa9529a..1e701ce 100644
--- a/include/freetype/ftcache.h
+++ b/include/freetype/ftcache.h
@@ -200,7 +200,7 @@
                                           FT_ULong            max_bytes,
                                           FTC_Face_Requester  requester,
                                           FT_Pointer          req_data,
-                                          FTC_Manager*        amanager );
+                                          FTC_Manager        *amanager );
 
 
   /*************************************************************************/
@@ -212,7 +212,7 @@
   /*    Empties a given cache manager.  This simply gets rid of all the    */
   /*    currently cached FT_Face & FT_Size objects within the manager.     */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    manager :: A handle to the manager.                                */
   /*                                                                       */
   FT_EXPORT( void )  FTC_Manager_Reset( FTC_Manager  manager );
@@ -266,7 +266,7 @@
   /*                                                                       */
   FT_EXPORT( FT_Error )  FTC_Manager_Lookup_Face( FTC_Manager  manager,
                                                   FTC_FaceID   face_id,
-                                                  FT_Face*     aface );
+                                                  FT_Face     *aface );
 
 
   /*************************************************************************/
@@ -283,7 +283,7 @@
   /*                                                                       */
   /*    size_id :: The ID of the `font size' to use.                       */
   /*                                                                       */
-  /* <InOut>                                                               */
+  /* <Output>                                                              */
   /*    aface   :: A pointer to the handle of the face object.  Set it to  */
   /*               zero if you don't need it.                              */
   /*                                                                       */
@@ -310,8 +310,8 @@
   /*                                                                       */
   FT_EXPORT( FT_Error )  FTC_Manager_Lookup_Size( FTC_Manager  manager,
                                                   FTC_Font     font,
-                                                  FT_Face*     aface,
-                                                  FT_Size*     asize );
+                                                  FT_Face     *aface,
+                                                  FT_Size     *asize );
 
 
   /* a cache class is used to describe a unique cache type to the manager */
@@ -323,7 +323,7 @@
   FT_EXPORT( FT_Error )  FTC_Manager_Register_Cache(
                            FTC_Manager       manager,
                            FTC_Cache_Class*  clazz,
-                           FTC_Cache*        acache );
+                           FTC_Cache        *acache );
 
 
 #ifdef __cplusplus
diff --git a/include/freetype/ftmac.h b/include/freetype/ftmac.h
index 4664588..42f1c03 100644
--- a/include/freetype/ftmac.h
+++ b/include/freetype/ftmac.h
@@ -67,7 +67,7 @@
                                FT_Library  library,
                                Handle      fond,
                                FT_Long     face_index,
-                               FT_Face*    aface );
+                               FT_Face    *aface );
 
 
 #ifdef __cplusplus
@@ -76,3 +76,6 @@
 
 
 #endif /* FT_MAC_H */
+
+
+/* END */
diff --git a/include/freetype/ftmodule.h b/include/freetype/ftmodule.h
index f8d3251..0552783 100644
--- a/include/freetype/ftmodule.h
+++ b/include/freetype/ftmodule.h
@@ -111,9 +111,10 @@
   /* <Description>                                                         */
   /*    Adds a new module to a given library instance.                     */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    library :: A handle to the library object.                         */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    clazz   :: A pointer to class descriptor for the module.           */
   /*                                                                       */
   /* <Return>                                                              */
@@ -159,9 +160,10 @@
   /* <Description>                                                         */
   /*    Removes a given module from a library instance.                    */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    library :: A handle to a library object.                           */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    module  :: A handle to a module object.                            */
   /*                                                                       */
   /* <Return>                                                              */
@@ -194,7 +196,7 @@
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_New_Library( FT_Memory    memory,
-                                         FT_Library*  library );
+                                         FT_Library  *alibrary );
 
 
   /*************************************************************************/
@@ -228,9 +230,10 @@
   /*    Sets a debug hook function for debugging the interpreter of a font */
   /*    format.                                                            */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    library    :: A handle to the library object.                      */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    hook_index :: The index of the debug hook.  You should use the     */
   /*                  values defined in ftobjs.h, e.g.                     */
   /*                  FT_DEBUG_HOOK_TRUETYPE                               */
diff --git a/include/freetype/ftnames.h b/include/freetype/ftnames.h
index 21abdee..87517e1 100644
--- a/include/freetype/ftnames.h
+++ b/include/freetype/ftnames.h
@@ -118,7 +118,7 @@
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Get_Sfnt_Name( FT_Face       face,
                                            FT_UInt       index,
-                                           FT_SfntName*  aname );
+                                           FT_SfntName  *aname );
 
 
 #ifdef __cplusplus
diff --git a/include/freetype/ftrender.h b/include/freetype/ftrender.h
index a92bc2b..aab57a7 100644
--- a/include/freetype/ftrender.h
+++ b/include/freetype/ftrender.h
@@ -156,9 +156,10 @@
   /* <Description>                                                         */
   /*    Sets the current renderer to use, and set additional mode.         */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    library    :: A handle to the library object.                      */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    renderer   :: A handle to the renderer object.                     */
   /*                                                                       */
   /*    num_params :: The number of additional parameters.                 */
diff --git a/include/freetype/internal/ftcalc.h b/include/freetype/internal/ftcalc.h
index 382c338..2b1745a 100644
--- a/include/freetype/internal/ftcalc.h
+++ b/include/freetype/internal/ftcalc.h
@@ -62,11 +62,11 @@
 
   FT_EXPORT( void )  FT_Add64( FT_Int64*  x,
                                FT_Int64*  y,
-                               FT_Int64*  z );
+                               FT_Int64  *z );
 
   FT_EXPORT( void )  FT_MulTo64( FT_Int32   x,
                                  FT_Int32   y,
-                                 FT_Int64*  z );
+                                 FT_Int64  *z );
 
   FT_EXPORT( FT_Int32 )  FT_Div64by32( FT_Int64*  x,
                                        FT_Int32   y );
diff --git a/include/freetype/freetype.h b/include/freetype/freetype.h
index cae2fa3..f9e44f9 100644
--- a/include/freetype/freetype.h
+++ b/include/freetype/freetype.h
@@ -1168,12 +1168,12 @@
   /*    that are registered by this function is determined at build time.  */
   /*                                                                       */
   /* <Output>                                                              */
   /*    library :: A handle to a new library object.                       */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
-  FT_EXPORT( FT_Error )  FT_Init_FreeType( FT_Library*  library );
+  FT_EXPORT( FT_Error )  FT_Init_FreeType( FT_Library  *alibrary );
 
 
   /*************************************************************************/
@@ -1349,13 +1349,13 @@
   /*    FT_New_Face() can be used to determine and/or check the font       */
   /*    format of a given font resource.  If the `face_index' field is     */
   /*    negative, the function will _not_ return any face handle in        */
   /*    `*face'.  Its return value should be 0 if the resource is          */
   /*    recognized, or non-zero if not.                                    */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_New_Face( FT_Library   library,
                                       const char*  filepathname,
                                       FT_Long      face_index,
-                                      FT_Face*     face );
+                                      FT_Face     *aface );
 
 
   /*************************************************************************/
@@ -1378,7 +1378,7 @@
   /*    face_index :: The index of the face within the resource.  The      */
   /*                  first face has index 0.                              */
   /* <Output>                                                              */
   /*    face       :: A handle to a new face object.                       */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
@@ -1395,14 +1395,14 @@
   /*    FT_New_Memory_Face() can be used to determine and/or check the     */
   /*    font format of a given font resource.  If the `face_index' field   */
   /*    is negative, the function will _not_ return any face handle in     */
   /*    `*face'.  Its return value should be 0 if the resource is          */
   /*    recognized, or non-zero if not.                                    */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_New_Memory_Face( FT_Library  library,
                                              FT_Byte*    file_base,
                                              FT_Long     file_size,
                                              FT_Long     face_index,
-                                             FT_Face*    face );
+                                             FT_Face    *aface );
 
 
   /*************************************************************************/
@@ -1448,7 +1448,7 @@
   FT_EXPORT( FT_Error )  FT_Open_Face( FT_Library     library,
                                        FT_Open_Args*  args,
                                        FT_Long        face_index,
-                                       FT_Face*       face );
+                                       FT_Face       *aface );
 
 
   /*************************************************************************/
@@ -1496,9 +1496,10 @@
   /*    This function is similar to FT_Attach_File() with the exception    */
   /*    that it reads the attachment from an arbitrary stream.             */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    face       :: The target face object.                              */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    parameters :: A pointer to an FT_Open_Args structure used to       */
   /*                  describe the input stream to FreeType.               */
   /* <Return>                                                              */
@@ -1613,10 +1614,11 @@
   /*    A function used to load a single glyph within a given glyph slot,  */
   /*    for a given size.                                                  */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    face        :: A handle to the target face object where the glyph  */
   /*                   will be loaded.                                     */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    glyph_index :: The index of the glyph in the font file.            */
   /*                                                                       */
   /*    load_flags  :: A flag indicating what to load for this glyph.  The */
@@ -1651,10 +1653,11 @@
   /*    A function used to load a single glyph within a given glyph slot,  */
   /*    for a given size, according to its character code.                 */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    face        :: A handle to a target face object where the glyph    */
   /*                   will be loaded.                                     */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    char_code   :: The glyph's character code, according to the        */
   /*                   current charmap used in the face.                   */
   /*                                                                       */
@@ -1968,10 +1971,11 @@
   /*    inspecting the glyph image format, find the relevant renderer, and */
   /*    invoke it.                                                         */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    slot        :: A handle to the glyph slot containing the image to  */
   /*                   convert.                                            */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    render_mode :: This is the render mode used to render the glyph    */
   /*                   image into a bitmap.  See FT_Render_Mode for a list */
   /*                   of possible values.                                 */
@@ -2031,7 +2035,7 @@
   /*                   kerning vector.                                     */
   /*                                                                       */
   /* <Output>                                                              */
   /*    kerning     :: The kerning vector.  This is in font units for      */
   /*                   scalable formats, and in pixels for fixed-sizes     */
   /*                   formats.                                            */
   /*                                                                       */
@@ -2048,7 +2052,7 @@
                                          FT_UInt     left_glyph,
                                          FT_UInt     right_glyph,
                                          FT_UInt     kern_mode,
-                                         FT_Vector*  kerning );
+                                         FT_Vector  *akerning );
 
 
   /*************************************************************************/
@@ -2065,12 +2069,13 @@
   /*                                                                       */
   /*    glyph_index :: The glyph index.                                    */
   /*                                                                       */
-  /*    buffer      :: A pointer to a target buffer where the name will be */
-  /*                   copied to.                                          */
-  /*                                                                       */
   /*    buffer_max  :: The maximal number of bytes available in the        */
   /*                   buffer.                                             */
   /*                                                                       */
+  /* <Output>                                                              */
+  /*    buffer      :: A pointer to a target buffer where the name will be */
+  /*                   copied to.                                          */
+  /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
@@ -2101,9 +2106,10 @@
   /*    Selects a given charmap by its encoding tag (as listed in          */
   /*    `freetype.h').                                                     */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    face     :: A handle to the source face object.                    */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    encoding :: A handle to the selected charmap.                      */
   /*                                                                       */
   /* <Return>                                                              */
@@ -2126,8 +2132,10 @@
   /*    Selects a given charmap for character code to glyph index          */
   /*    decoding.                                                          */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    face     :: A handle to the source face object.                    */
+  /*                                                                       */
+  /* <Input>                                                               */
   /*    charmap  :: A handle to the selected charmap.                      */
   /*                                                                       */
   /* <Return>                                                              */
@@ -1168,12 +1168,12 @@
   /*                                                                       */
   /* <Output>                                                              */
-  /*    library :: A handle to a new library object.                       */
+  /*    alibrary :: A handle to a new library object.                      */
   /*                                                                       */
   /* <Return>                                                              */
@@ -1349,13 +1349,13 @@
   /*    format of a given font resource.  If the `face_index' field is     */
   /*    negative, the function will _not_ return any face handle in        */
-  /*    `*face'.  Its return value should be 0 if the resource is          */
+  /*    `aface'.  Its return value should be 0 if the resource is          */
   /*    recognized, or non-zero if not.                                    */
   /*                                                                       */
@@ -1378,7 +1378,7 @@
   /*                  first face has index 0.                              */
   /* <Output>                                                              */
-  /*    face       :: A handle to a new face object.                       */
+  /*    aface      :: A handle to a new face object.                       */
   /*                                                                       */
   /* <Return>                                                              */
@@ -1395,14 +1395,14 @@
   /*    font format of a given font resource.  If the `face_index' field   */
   /*    is negative, the function will _not_ return any face handle in     */
-  /*    `*face'.  Its return value should be 0 if the resource is          */
+  /*    `aface'.  Its return value should be 0 if the resource is          */
   /*    recognized, or non-zero if not.                                    */
   /*                                                                       */
@@ -2031,7 +2035,7 @@
   /*                                                                       */
   /* <Output>                                                              */
-  /*    kerning     :: The kerning vector.  This is in font units for      */
+  /*    akerning    :: The kerning vector.  This is in font units for      */
   /*                   scalable formats, and in pixels for fixed-sizes     */
   /*                   formats.                                            */
diff --git a/include/freetype/ftbbox.h b/include/freetype/ftbbox.h
index 629e231..db73d9f 100644
--- a/include/freetype/ftbbox.h
+++ b/include/freetype/ftbbox.h
@@ -53,13 +53,13 @@
   /*    outline :: A pointer to the source outline.                        */
   /*                                                                       */
   /* <Output>                                                              */
   /*    bbox    :: The outline's exact bounding box.                       */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Outline_Get_BBox( FT_Outline*  outline,
-                                              FT_BBox*     bbox );
+                                              FT_BBox     *abbox );
 
 
 #ifdef __cplusplus
@@ -53,13 +53,13 @@
   /*                                                                       */
   /* <Output>                                                              */
-  /*    bbox    :: The outline's exact bounding box.                       */
+  /*    abbox   :: The outline's exact bounding box.                       */
   /*                                                                       */
   /* <Return>                                                              */
diff --git a/include/freetype/ftglyph.h b/include/freetype/ftglyph.h
index 7aca54f..d1dfbfd 100644
--- a/include/freetype/ftglyph.h
+++ b/include/freetype/ftglyph.h
@@ -162,7 +162,7 @@
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Get_Glyph( FT_GlyphSlot  slot,
-                                       FT_Glyph*     aglyph );
+                                       FT_Glyph     *aglyph );
 
 
   /*************************************************************************/
@@ -184,7 +184,7 @@
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Glyph_Copy( FT_Glyph   source,
-                                        FT_Glyph*  target );
+                                        FT_Glyph  *target );
 
 
   /*************************************************************************/
@@ -195,9 +195,10 @@
   /* <Description>                                                         */
   /*    Transforms a glyph image if its format is scalable.                */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    glyph  :: A handle to the target glyph object.                     */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    matrix :: A pointer to a 2x2 matrix to apply.                      */
   /*                                                                       */
   /*    delta  :: A pointer to a 2d vector to apply.  Coordinates are      */
@@ -232,7 +233,16 @@
   /*    FT_Glyph_Get_CBox                                                  */
   /*                                                                       */
   /* <Description>                                                         */
-  /*    Returns the glyph image's bounding box.                            */
+  /*    Returns a glyph's `control box'.  The control box encloses all the */
+  /*    outline's points, including Bezier control points.  Though it      */
+  /*    coincides with the exact bounding box for most glyphs, it can be   */
+  /*    slightly larger in some situations (like when rotating an outline  */
+  /*    which contains Bezier outside arcs).                               */
+  /*                                                                       */
+  /*    Computing the control box is very fast, while getting the bounding */
+  /*    box can take much more time as it needs to walk over all segments  */
+  /*    and arcs in the outline.  To get the latter, you can use the       */
+  /*    `ftbbox' component which is dedicated to this single task.         */
   /*                                                                       */
   /* <Input>                                                               */
   /*    glyph :: A handle to the source glyph object.                      */
@@ -241,8 +251,8 @@
   /*             bounding box values.                                      */
   /*                                                                       */
   /* <Output>                                                              */
   /*    box   :: The glyph bounding box.  Coordinates are expressed in     */
   /*             1/64th of pixels if it is grid-fitted.                    */
   /*                                                                       */
   /* <Note>                                                                */
   /*    Coordinates are relative to the glyph origin, using the Y-upwards  */
@@ -281,7 +291,7 @@
   /*                                                                       */
   FT_EXPORT( void )  FT_Glyph_Get_CBox( FT_Glyph  glyph,
                                         FT_UInt   bbox_mode,
-                                        FT_BBox*  cbox );
+                                        FT_BBox  *acbox );
 
 
   /*************************************************************************/
@@ -293,7 +303,7 @@
   /*    Converts a given glyph object to a bitmap glyph object.            */
   /*                                                                       */
   /* <InOut>                                                               */
-  /*    glyph       :: A pointer to a handle to the target glyph.          */
+  /*    the_glyph   :: A pointer to a handle to the target glyph.          */
   /*                                                                       */
   /* <Input>                                                               */
   /*    render_mode :: A set of bit flags that describe how the data is    */
@@ -241,8 +251,8 @@
   /*                                                                       */
   /* <Output>                                                              */
-  /*    box   :: The glyph bounding box.  Coordinates are expressed in     */
-  /*             1/64th of pixels if it is grid-fitted.                    */
+  /*    acbox :: The glyph coordinate bounding box.  Coordinates are       */
+  /*             expressed in 1/64th of pixels if it is grid-fitted.       */
   /*                                                                       */
   /* <Note>                                                                */
diff --git a/include/freetype/ftmm.h b/include/freetype/ftmm.h
index 3d92c82..6c9b1dc 100644
--- a/include/freetype/ftmm.h
+++ b/include/freetype/ftmm.h
@@ -100,16 +100,16 @@
   /*    Retrieves the Multiple Master descriptor of a given font.          */
   /*                                                                       */
   /* <Input>                                                               */
-  /*    face   :: A handle to the source face.                             */
+  /*    face    :: A handle to the source face.                            */
   /*                                                                       */
   /* <Output>                                                              */
   /*    master :: The Multiple Masters descriptor.                         */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Get_Multi_Master( FT_Face           face,
-                                              FT_Multi_Master*  master );
+                                              FT_Multi_Master  *amaster );
 
 
   /*************************************************************************/
@@ -121,13 +121,14 @@
   /*    For Multiple Masters fonts, choose an interpolated font design     */
   /*    through design coordinates.                                        */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    face       :: A handle to the source face.                         */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    num_coords :: The number of design coordinates (must be equal to   */
   /*                  the number of axes in the font).                     */
   /*                                                                       */
-  /*    coords     :: The design coordinates.                              */
+  /*    coords     :: An array of design coordinates.                      */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
@@ -147,14 +148,15 @@
   /*    For Multiple Masters fonts, choose an interpolated font design     */
   /*    through normalized blend coordinates.                              */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    face       :: A handle to the source face.                         */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    num_coords :: The number of design coordinates (must be equal to   */
   /*                  the number of axes in the font).                     */
   /*                                                                       */
-  /*    coords     :: The design coordinates (each one must be between 0   */
-  /*                  and 1.0).                                            */
+  /*    coords     :: The design coordinates array (each element must be   */
+  /*                  between 0 and 1.0).                                  */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
@@ -100,16 +100,16 @@
   /*                                                                       */
   /* <Output>                                                              */
-  /*    master :: The Multiple Masters descriptor.                         */
+  /*    amaster :: The Multiple Masters descriptor.                        */
   /*                                                                       */
   /* <Return>                                                              */
diff --git a/include/freetype/ftoutln.h b/include/freetype/ftoutln.h
index 2862da9..8010e1b 100644
--- a/include/freetype/ftoutln.h
+++ b/include/freetype/ftoutln.h
@@ -45,6 +45,7 @@
   /*    interface :: A table of `emitters', i.e,. function pointers called */
   /*                 during decomposition to indicate path operations.     */
   /*                                                                       */
+  /* <InOut>                                                               */
   /*    user      :: A typeless pointer which is passed to each emitter    */
   /*                 during the decomposition.  It can be used to store    */
   /*                 the state during the decomposition.                   */
@@ -77,7 +78,7 @@
   /*    numContours :: The maximal number of contours within the outline.  */
   /*                                                                       */
   /* <Output>                                                              */
   /*    outline     :: A handle to the new outline.  NULL in case of       */
   /*                   error.                                              */
   /*                                                                       */
   /* <Return>                                                              */
@@ -93,14 +94,14 @@
   FT_EXPORT( FT_Error )  FT_Outline_New( FT_Library   library,
                                          FT_UInt      numPoints,
                                          FT_Int       numContours,
-                                         FT_Outline*  outline );
+                                         FT_Outline  *anoutline );
 
 
   FT_EXPORT( FT_Error )  FT_Outline_New_Internal(
                            FT_Memory    memory,
                            FT_UInt      numPoints,
                            FT_Int       numContours,
-                           FT_Outline*  outline );
+                           FT_Outline  *anoutline );
 
 
   /*************************************************************************/
@@ -127,7 +128,7 @@
   /*    If the outline's `owner' field is not set, only the outline        */
   /*    descriptor will be released.                                       */
   /*                                                                       */
-  /*    The reason why this function takes an `outline' parameter is       */
+  /*    The reason why this function takes an `library' parameter is       */
   /*    simply to use FT_Free().                                           */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Outline_Done( FT_Library   library,
@@ -159,13 +160,13 @@
   /*    outline :: A pointer to the source outline descriptor.             */
   /*                                                                       */
   /* <Output>                                                              */
   /*    cbox    :: The outline's control box.                              */
   /*                                                                       */
   /* <MT-Note>                                                             */
   /*    Yes.                                                               */
   /*                                                                       */
   FT_EXPORT( void )  FT_Outline_Get_CBox( FT_Outline*  outline,
-                                          FT_BBox*     cbox );
+                                          FT_BBox     *acbox );
 
 
   /*************************************************************************/
@@ -176,9 +177,10 @@
   /* <Description>                                                         */
   /*    Applies a simple translation to the points of an outline.          */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    outline :: A pointer to the target outline descriptor.             */
   /*                                                                       */
+  /* <Input>                                                               */
   /*    xOffset :: The horizontal offset.                                  */
   /*                                                                       */
   /*    yOffset :: The vertical offset.                                    */
@@ -211,7 +213,7 @@
   /*    FreeType error code.  0 means success.                             */
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Outline_Copy( FT_Outline*  source,
-                                          FT_Outline*  target );
+                                          FT_Outline  *target );
 
 
   /*************************************************************************/
@@ -247,7 +249,7 @@
   /*    Reverses the drawing direction of an outline.  This is used to     */
   /*    ensure consistent fill conventions for mirrored glyphs.            */
   /*                                                                       */
-  /* <Input>                                                               */
+  /* <InOut>                                                               */
   /*    outline :: A pointer to the target outline descriptor.             */
   /*                                                                       */
   /* <Note>                                                                */
@@ -274,7 +276,8 @@
   /*                                                                       */
   /*    outline :: A pointer to the source outline descriptor.             */
   /*                                                                       */
   /*    map     :: A pointer to the target bitmap descriptor.              */
   /*                                                                       */
   /* <Return>                                                              */
   /*    FreeType error code.  0 means success.                             */
@@ -291,7 +294,7 @@
   /*                                                                       */
   FT_EXPORT( FT_Error )  FT_Outline_Get_Bitmap( FT_Library   library,
                                                 FT_Outline*  outline,
-                                                FT_Bitmap*   bitmap );
+                                                FT_Bitmap   *abitmap );
 
 
   /*************************************************************************/
@@ -310,6 +313,7 @@
   /*                                                                       */
   /*    outline :: A pointer to the source outline descriptor.             */
   /*                                                                       */
+  /* <InOut>                                                               */
   /*    params  :: A pointer to a FT_Raster_Params structure used to       */
   /*               describe the rendering operation.                       */
   /*                                                                       */
@@ -77,7 +78,7 @@
   /*                                                                       */
   /* <Output>                                                              */
-  /*    outline     :: A handle to the new outline.  NULL in case of       */
+  /*    anoutline   :: A handle to the new outline.  NULL in case of       */
   /*                   error.                                              */
   /*                                                                       */
@@ -159,13 +160,13 @@
   /*                                                                       */
   /* <Output>                                                              */
-  /*    cbox    :: The outline's control box.                              */
+  /*    acbox   :: The outline's control box.                              */
   /*                                                                       */
   /* <MT-Note>                                                             */
@@ -274,7 +276,8 @@
   /*    outline :: A pointer to the source outline descriptor.             */
   /*                                                                       */
-  /*    map     :: A pointer to the target bitmap descriptor.              */
+  /* <Output>                                                              */
+  /*    abitmap :: A pointer to the target bitmap descriptor.              */
   /*                                                                       */
   /* <Return>                                                              */